@@ -58,7 +58,7 @@ function roundcube_browser()
   this.dom = document.getElementById ? true : false;
   this.dom2 = document.addEventListener && document.removeEventListener;
 
-  this.edge = this.agent_lc.indexOf(' edge/') > 0;
+  this.edge = this.agent_lc.indexOf(' edge/') > 0 || this.agent_lc.indexOf(' edg/') > 0; // "edg" in Chromium based Edge
   this.webkit = !this.edge && this.agent_lc.indexOf('applewebkit') > 0;
   this.ie = (document.all && !window.opera) || (this.win && this.agent_lc.indexOf('trident/') > 0);
 
@@ -77,12 +77,25 @@ function roundcube_browser()
   }
 
   if (!this.vendver) {
-    // common version strings
-    this.vendver = /(opera|opr|khtml|chrome|safari|applewebkit|msie)(\s|\/)([0-9\.]+)/.test(this.agent_lc) ? parseFloat(RegExp.$3) : 0;
+    if (this.ie)
+      pattern = /(msie|rv)(\s|:)([0-9\.]+)/;
+    else if (this.edge)
+      pattern = /(edge?)(\/)([0-9\.]+)/;
+    else if (this.opera)
+      pattern = /(opera|opr)(\/)([0-9\.]+)/;
+    else if (this.konq)
+      pattern = /(konqueror)(\/)([0-9\.]+)/;
+    else if (this.safari)
+      pattern = /(version)(\/)([0-9\.]+)/;
+    else if (this.chrome)
+      pattern = /(chrome)(\/)([0-9\.]+)/;
+    else if (this.mz)
+      pattern = /(firefox)(\/)([0-9\.]+)/;
+    else
+      pattern = /(khtml|safari|applewebkit|rv)(\s|\/|:)([0-9\.]+)/;
 
-    // any other (Mozilla, Camino, IE>=11)
-    if (!this.vendver)
-      this.vendver = /rv:([0-9\.]+)/.test(this.agent) ? parseFloat(RegExp.$1) : 0;
+    // common version strings
+    this.vendver = pattern.test(this.agent_lc) ? parseFloat(RegExp.$3) : 0;
   }
 
   // get real language out of safari's user agent
@@ -95,14 +108,6 @@ function roundcube_browser()
   this.pointer = typeof window.PointerEvent == "function";
   this.cookies = n.cookieEnabled;
 
-  // test for XMLHTTP support
-  this.xmlhttp_test = function()
-  {
-    var activeX_test = new Function("try{var o=new ActiveXObject('Microsoft.XMLHTTP');return true;}catch(err){return false;}");
-    this.xmlhttp = window.XMLHttpRequest || (('ActiveXObject' in window) && activeX_test());
-    return this.xmlhttp;
-  };
-
   // set class names to html tag according to the current user agent detection
   // this allows browser-specific css selectors like "html.chrome .someclass"
   this.set_html_class = function()
@@ -111,6 +116,8 @@ function roundcube_browser()
 
     if (this.ie)
       classname += ' ms ie ie'+parseInt(this.vendver);
+    else if (this.edge && this.vendver > 74)
+      classname += ' chrome';
     else if (this.edge)
       classname += ' ms edge';
     else if (this.opera)
@@ -422,11 +429,10 @@ function rcube_check_email(input, inline, count, strict)
       ipv6 = '\\[IPv6:[0-9a-f:.]+\\]',
       ip_addr = '(' + ipv4 + ')|(' + ipv6 + ')',
       // Use simplified domain matching, because we need to allow Unicode characters here
-      // So, e-mail address should be validated also on server side after idn_to_ascii() use
-      //domain_literal = '\\x5b('+dtext+'|'+quoted_pair+')*\\x5d',
-      //sub_domain = '('+atom+'|'+domain_literal+')',
-      // allow punycode/unicode top-level domain
-      domain = '(('+ip_addr+')|(([^@\\x2e]+\\x2e)+([^\\x00-\\x40\\x5b-\\x60\\x7b-\\x7f]{2,}|xn--[a-z0-9]{2,})))',
+      // So, e-mail address should be validated also on server side after idn_to_ascii()
+      // Allow punycode/unicode top-level domains, allow extended domains (#5588)
+      // Allow a domain ending with .s (#8854)
+      domain = '(('+ip_addr+')|(([^@.]+\\.)+([^\\x00-\\x2f\\x3a-\\x40\\x5b-\\x60\\x7b-\\x7f]{2,}|s|xn--[a-z0-9]{2,})))',
       // ICANN e-mail test (http://idn.icann.org/E-mail_test)
       icann_domains = [
         '\\u0645\\u062b\\u0627\\u0644\\x2e\\u0625\\u062e\\u062a\\u0628\\u0627\\u0631',
@@ -449,8 +455,10 @@ function rcube_check_email(input, inline, count, strict)
       rx_flag = count ? 'ig' : 'i',
       rx = inline ? new RegExp('(^|<|'+delim+')'+addr_spec+'($|>|'+delim+')', rx_flag) : new RegExp('^'+addr_spec+'$', 'i');
 
-  if (count)
-    return input.match(rx).length;
+  if (count) {
+    var re = input.match(rx);
+    return re ? re.length : 0;
+  }
 
   return rx.test(input);
 };
@@ -473,14 +481,12 @@ function rcube_clone_object(obj)
 // make a string URL safe (and compatible with PHP's rawurlencode())
 function urlencode(str)
 {
-  if (window.encodeURIComponent)
-    return encodeURIComponent(str).replace('*', '%2A');
-
-  return escape(str)
-    .replace('+', '%2B')
+  return encodeURIComponent(str)
     .replace('*', '%2A')
-    .replace('/', '%2F')
-    .replace('@', '%40');
+    .replace('(', '%28')
+    .replace(')', '%29')
+    .replace('!', '%21')
+    .replace("'", '%27');
 };
 
 
@@ -541,7 +547,7 @@ function setCookie(name, value, expires, path, domain, secure)
       (expires ? "; expires=" + expires.toGMTString() : "") +
       (path ? "; path=" + path : "") +
       (domain ? "; domain=" + domain : "") +
-      (secure ? "; secure" : "");
+      (secure ? "; secure" : "") + '; SameSite=Lax';
 
   document.cookie = curCookie;
 };
